@@ -5,7 +5,7 @@ use utf8;
 
 package Path::IsDev;
 
-our $VERSION = '1.001001';
+our $VERSION = '1.001003';
 
 # ABSTRACT: Determine if a given Path resembles a development source tree
 
@@ -22,244 +22,6 @@ our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 use Sub::Exporter -setup => { exports => [ is_dev => \&_build_is_dev, ], };
 
 our $ENV_KEY_DEBUG = 'PATH_ISDEV_DEBUG';
@@ -334,7 +96,7 @@ Path::IsDev - Determine if a given Path resembles a development source tree
 
 =head1 VERSION
 
-version 1.001001
+version 1.001003
 
 =head1 SYNOPSIS
 
@@ -385,6 +147,16 @@ it using
 
 That is, no C<set> specification is applicable, so you'll only get the "default".
 
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Path::IsDev",
+    "interface":"exporter"
+}
+
+
+=end MetaPOD::JSON
+
 =head1 UNDERSTANDING AND DEBUGGING THIS MODULE
 
 Understanding how this module works, is critical to understand where you can use it, and the consequences of using it.
@@ -597,23 +369,13 @@ And to that effect, this module does nothing to "lock down" that mechanism, and
 to B<NOT> force a set, unless you B<NEED> to, and strongly suggests that forcing a set for the purpose of security will achieve
 no real improvement in security, while simultaneously reducing utility.
 
-=begin MetaPOD::JSON v1.1.0
-
-{
-    "namespace":"Path::IsDev",
-    "interface":"exporter"
-}
-
-
-=end MetaPOD::JSON
-
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
